@@ -789,10 +789,8 @@ class ImplicitCoKriging(object):
     @_setdoc(Surfaces.add_surface.__doc__, indent=False)
     def add_surfaces(self, surface_list: Union[str, list], update_df=True):
         self._surfaces.add_surface(surface_list, update_df)
-        self._surface_points.df['surface'].cat.add_categories(surface_list,
-                                                              inplace=True)
-        self._orientations.df['surface'].cat.add_categories(surface_list,
-                                                            inplace=True)
+        self._surface_points.df['surface'] = self._surface_points.df['surface'].cat.add_categories(surface_list)
+        self._orientations.df['surface'] = self._orientations.df['surface'].cat.add_categories(surface_list)
         self.update_structure()
         return self._surfaces
 
@@ -997,12 +995,20 @@ class ImplicitCoKriging(object):
 
         """
 
-        coord_x_name = kwargs.get('coord_x_name') if 'coord_x_name' in kwargs \
-            else self._check_possible_column_names(table, ['X', 'x'])
-        coord_y_name = kwargs.get('coord_y_name') if 'coord_y_name' in kwargs \
-            else self._check_possible_column_names(table, ['Y', 'y'])
-        coord_z_name = kwargs.get('coord_z_name') if 'coord_z_name' in kwargs \
-            else self._check_possible_column_names(table, ['Z', 'z'])
+        try:
+            coord_x_name = kwargs.get('coord_x_name') if 'coord_x_name' in kwargs \
+                else self._check_possible_column_names(table, ['X', 'x'])
+            coord_y_name = kwargs.get('coord_y_name') if 'coord_y_name' in kwargs \
+                else self._check_possible_column_names(table, ['Y', 'y'])
+        except IndexError:
+            raise ValueError('X and Y coordinates columns/values missing')
+
+        try:
+            coord_z_name = kwargs.get('coord_z_name') if 'coord_z_name' in kwargs \
+                else self._check_possible_column_names(table, ['Z', 'z'])
+        except IndexError:
+            raise ValueError('Z coordinates column/values missing')
+        
         surface_name = kwargs.get('surface_name') if 'surface_name' in kwargs \
             else self._check_possible_column_names(table,
                                                    ['surface', 'Surface', 'surfaces',
