@@ -15,7 +15,7 @@
     along with gempy.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Module with classes and methods to visualized structural geology data and potential fields of the regional modelling based on
+Module with classes and methods to visualize structural geology data and potential fields of the regional modelling based on
 the potential field method.
 Tested on Ubuntu 14
 
@@ -1177,7 +1177,7 @@ class vtkVisualization(object):
 
         if lith_block is None:
             lith_block = geo_data.solutions.lith_block
-        lith = lith_block.reshape((nx, ny, nz))
+        lith = lith_block.reshape((nx, ny, nz)).flatten(order='F')
         out = pv.RectilinearGrid(x,y,z)
         out['Lithology'] = lith
         out.save(path+'_lith_block.vtr')
